package net.wanji.utc.service.runninginfo.impl;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.databus.po.SignalStatusLogPO;
import net.wanji.databus.vo.LightsStatusVO;
import net.wanji.utc.cache.CrossInfoCache;
import net.wanji.utc.cache.UtcFeignClientCache;
import net.wanji.utc.service.runninginfo.WanJiCommonRunningStatusService;
import net.wanji.utc.util.HttpRestUtil;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.*;

/**
 * @author duanruiming
 * @date 2023/01/11 17:34
 */
@Slf4j
@Service
@RequiredArgsConstructor
public class WanJiCommonRunningStatusServiceImpl implements WanJiCommonRunningStatusService {

    private final HttpRestUtil httpRestUtil;
    @Value("url")
    private String rpcUri;
    private final CrossInfoCache crossInfoCache;
    private final UtcFeignClientCache utcFeignClientCache;

    @Override
    public List<SignalStatusLogPO> runningStatus(List<String> crossIdList) throws Exception {
        Set<String> set = new HashSet<>();
        for (String crossId : crossIdList) {
            String manufacturerIdCode = crossInfoCache.getManufacturerCodeByCrossId(crossId);
            set.add(manufacturerIdCode);
        }
        List<SignalStatusLogPO> result = new ArrayList<>();
        for (String manufacturerIdCode : set) {
            JsonViewObject jsonViewObject = utcFeignClientCache.getUtcFeignClientService(manufacturerIdCode).runningStatusAlarm();
            result = (List<SignalStatusLogPO>) jsonViewObject.getContent();
        }
        return result;
    }

    @Override
    public List<LightsStatusVO> lightsStatus(List<String> crossIdList) throws Exception {
        Set<String> set = new HashSet<>();
        for (String crossId : crossIdList) {
            String manufacturerIdCode = crossInfoCache.getManufacturerCodeByCrossId(crossId);
            set.add(manufacturerIdCode);
        }
        List<LightsStatusVO> result = new ArrayList<>();
        for (String manufacturerIdCode : set) {
            JsonViewObject jsonViewObject = utcFeignClientCache.getUtcFeignClientService(manufacturerIdCode).lightStatus();
            result = (List<LightsStatusVO>) jsonViewObject.getContent();
        }
        return result;
    }

    @Override
    public JsonViewObject rpcService(HttpRestUtil httpRestUtil, String url, Map<String, String> headers, String param) {
        return WanJiCommonRunningStatusService.super.rpcService(httpRestUtil, url, headers, param);
    }
}
